﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO.Ports;

namespace TalkToArduino
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            send_button.Enabled = false;

            //baud rates available
            int[] baudrates = {
                                  4800,
                                  9600,
                                  14400,
                                  19200,
                                  28800,
                                  38400,
                                  57600,
                                  115200
                              };
            foreach (int i in baudrates)
            {
                baudrate_combobox.Items.Add(Convert.ToString(i));
            }

            //availabe COM ports
            SerialPort tmp;
            foreach(string str in SerialPort.GetPortNames())
            {
                tmp = new SerialPort(str);
                if (tmp.IsOpen == false)
                    port_combobox.Items.Add(str);
            }
            

        }

        private void baudrate_combobox_SelectedIndexChanged(object sender, EventArgs e)
        {
            //sets baudrate
            serialPort.BaudRate = Convert.ToInt16(baudrate_combobox.Text);

            //enable send button?
            if (port_combobox.Text.CompareTo("") != 0)
                send_button.Enabled = true;
        }

        private void port_combobox_SelectedIndexChanged(object sender, EventArgs e)
        {
            serialPort.PortName = port_combobox.Text;

            try
            {
                //open serial port
                serialPort.Open();
                port_combobox.Enabled = false;

                //enable send button?
                if (baudrate_combobox.Text.CompareTo("") != 0)
                    send_button.Enabled = true;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "ERROR", MessageBoxButtons.OK, MessageBoxIcon.Error);
                port_combobox.Text = "";
            }


        }

        private void send_button_Click(object sender, EventArgs e)
        {
            try
            {
                //send message to Arduino
                serialPort.Write(message_textbox.Text);
                message_textbox.Text = "";
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message,"ERROR",MessageBoxButtons.OK,MessageBoxIcon.Error);
            }
        }

        private void message_textbox_Click(object sender, KeyPressEventArgs e)
        {
            //able to send message by pressing ENTER
            if (e.KeyChar == '\r')
            {
                send_button.PerformClick();
                e.Handled = true;
            }

        }
    }
}
