﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO.Ports;
using System.Threading;

namespace TalkToArduino
{
    public partial class Form1 : Form
    {
        const int toothSizeMin = 40;
        const int toothSizeMax = 151; 
        const int multiplierMin = 0;
        const int multiplierMax = 15;

        string teethStringToSend;

        public Form1()
        {
            InitializeComponent();

            serialPort.BaudRate = 9600;

            //Load available COM ports to fill combobox
            SerialPort tmp;
            foreach(string str in SerialPort.GetPortNames())
            {
                tmp = new SerialPort(str);
                if (tmp.IsOpen == false)
                    port_combobox.Items.Add(str);
            }           
        }

        private void port_combobox_SelectedIndexChanged(object sender, EventArgs e)
        {
            serialPort.PortName = port_combobox.Text;

            try
            {
                //open serial port
                serialPort.Open();
                port_combobox.Enabled = false;
                btnStart.Enabled = true;
                lblStatus.Text = "Connected to COM, not counting";
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "ERROR", MessageBoxButtons.OK, MessageBoxIcon.Error);
                port_combobox.Text = "";
                lblStatus.Text = "COM CONNECTION FAILURE";
            }
        }

        private void Form1_Load(object sender, EventArgs e)
        {

        }

        private void button3_Click(object sender, EventArgs e)
        {
            StopController();
        }

        private void StopController()
        {
            //Deal with enabled/disabled stuff
            btnTakePicture.Enabled = false;
            btnStop.Enabled = false;
            btnStart.Enabled = true;
            btnAdvance.Enabled = false;
            btnAdvance2.Enabled = false;
            btnRetard.Enabled = false;
            btnRetard2.Enabled = false;
            btnSet.Enabled = false;
            txtMultiplier.Enabled = false;
            txtToothSize.Enabled = false; 

            //Update status label
            lblStatus.Text = "Camera controller stopped";

            //Talk to arduino to stop process
            serialPort.Write("2");
        }

        private void btnAdvance_Click(object sender, EventArgs e)
        {
            serialPort.Write("4");
        }

        private void btnAdvance2_Click(object sender, EventArgs e)
        {
            serialPort.Write("5");
        }

        private void btnRetard_Click(object sender, EventArgs e)
        {
            serialPort.Write("6");
        }

        private void btnRetard2_Click(object sender, EventArgs e)
        {
            serialPort.Write("7");
        }

        private void btnSet_Click(object sender, EventArgs e)
        {
            int teethToSend = 0;
            int parsedValue;

            //Determine whether or not the value in txtToothSize.Text is an integer
            if (!int.TryParse(txtToothSize.Text, out parsedValue))
            {
                MessageBox.Show("Tooth size must be an integer.");
                return;
            }
            
            //Now, determine if the value in txtMultiplier.Text is an integer
            if (!int.TryParse(txtToothSize.Text, out parsedValue))
            {
                MessageBox.Show("Multiplier value must be an integer.");
                return;
            }


            //If they are both integers, make sure the integers are in a valid range. If so, send to serialPort. 
            int toothSize = Convert.ToInt16(txtToothSize.Text);
            int multiplier = Convert.ToInt16(txtMultiplier.Text);

            if (toothSize >= toothSizeMin && toothSize <= toothSizeMax && multiplier > multiplierMin && multiplier < multiplierMax)
            {
                teethToSend = toothSize * multiplier;

                //teethStringToSend = Convert.ToString(teethToSend) + "\n";

                serialPort.Write(Convert.ToString(teethToSend));
                //MessageBox.Show(Convert.ToString(teethToSend));

                //Update labels
                lblToothSize.Text = Convert.ToString(toothSize);
                lblMultiplier.Text = Convert.ToString(multiplier);
            }
            else if(toothSize < toothSizeMin || toothSize > toothSizeMax)
                MessageBox.Show("Tooth size must be a value between "+toothSizeMin+" and "+toothSizeMax);
            else if(multiplier < multiplierMin || multiplier > multiplierMax)
                MessageBox.Show("Multiplier must be a value between " + multiplierMin + " and " + multiplierMax);
        }

        private void btnStart_Click(object sender, EventArgs e)
        {
            //Send 5V to the proximity sensor
            serialPort.Write("1");

            //Give the arduino a count to start with 
            //serialPort.Write("330");

            //Enable the other buttons on the form
            btnTakePicture.Enabled = true;
            btnStop.Enabled = true;
            btnSet.Enabled = true;
            btnAdvance.Enabled = true;
            btnAdvance2.Enabled = true;
            btnRetard.Enabled = true;
            btnRetard2.Enabled = true;
            txtToothSize.Enabled = true;
            txtMultiplier.Enabled = true;

            //Disable this button
            btnStart.Enabled = false;

            //Update the Status label
            lblStatus.Text = "Connected to COM, sensor initiated && counting";
        }

        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            serialPort.Close();
        }

        private void btnTakePicture_Click(object sender, EventArgs e)
        {
            serialPort.Write("3");
        }
    }
}